@@ -12,7 +12,7 @@ use parent 'Evented::Object';
 use Scalar::Util qw(blessed weaken);
 use List::Util qw(first);
 
-our $VERSION = '4.09';
+our $VERSION = '4.10';
 
 =head1 NAME
 
@@ -658,4 +658,15 @@ sub dependent_companions {
     return @mods;
 }
 
+=head1 AUTHOR
+
+L<Mitchell Cooper|https://github.com/cooper> <cooper@cpan.org>
+
+Copyright E<copy> 2017. Released under New BSD license.
+
+Comments, complaints, and recommendations are accepted. Bugs may be reported on
+L<GitHub|https://github.com/cooper/evented-api-engine/issues>.
+
+=cut
+
 1;
